km3pipe.shell.Script
====================

.. currentmodule:: km3pipe.shell

.. autoclass:: Script

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Script.__init__
      ~Script.add
      ~Script.clear
      ~Script.cp
      ~Script.echo
      ~Script.iget
      ~Script.mkdir
      ~Script.mv
      ~Script.separator
   
   

   
   
   